@@ -209,7 +209,7 @@ DBIx::Mint::Schema - Class and relationship definitions for DBIx::Mint
  my $schema = DBIx::Mint->instance->schema;
 
  # Using a named schema:
- my $schema = DBIx::Mint->instance->schema( 'other' );
+ my $schema = DBIx::Mint::Schema->instance( 'other' );
 
  # which is the same as this:
  my $mint   = DBIx::Mint->instance('other');
@@ -274,9 +274,9 @@ Defines the primary key in the database. It can be a single field name or an arr
 
 Lets DBIx::Mint know that the pk is automatically generated by the database. It expects a boolean value. Optional; defaults to false.
 
-=item not_in_db
+=item fields_not_in_db
 
-Receives a list of attributes of the given class which are not stored in the database. They will be removed from the data before inserting or updating it into the database.
+Receives an array ref of attributes of the given class which are not stored in the database. They will be removed from the data before inserting or updating it into the database.
 
 =back
 
